st7/

;************************************************************************ 
; TITLE:                ST72334.ASM
; AUTHOR:               CMG Microcontroller Application Team
; DESCRIPTION:          ST72334 Register and memory mapping 
;
; Define here the micro RAM & ROM Size according to the sales type:
;
; #define ST72334N2   1   ;=>  8K ROM, 384 bytes RAM also available for ST72334J2
	#define ST72334N4    1   ;=> 16K ROM, 512 bytes RAM  also available for ST72334J4
;    
;************************************************************************
;************************************************************************

    

    BYTES           ; following addresses are 8 bit length

;********************************************************************
    segment byte at 0-71 'periph'
;********************************************************************

;**********************************************************************
;                        I/O Ports registers
;**********************************************************************
                
.PADR   DS.B    1       ; port A data register
.PADDR  DS.B    1       ; port A data direction register
.PAOR   DS.B    1       ; port A option register
        DS.B    1       ; not used

.PCDR   DS.B    1       ; port C data register
.PCDDR  DS.B    1       ; port C data direction register
.PCOR   DS.B    1       ; port C option register
        DS.B    1       ; not used     
           
.PBDR   DS.B    1       ; port B data register
.PBDDR  DS.B    1       ; port B data direction register
.PBOR   DS.B    1       ; port B option register
        DS.B    1       ; not used
        
.PEDR   DS.B    1       ; port E data register
.PEDDR  DS.B    1       ; port E data direction register 
.PEOR   DS.B    1       ; port E option register       
        DS.B    1       ; not used

.PDDR   DS.B    1       ; port D data register
.PDDDR  DS.B    1       ; port D data direction register  
.PDOR   DS.B    1       ; port D option register      
        DS.B    1       ; not used
        
.PFDR   DS.B    1       ; port F data register
.PFDDR  DS.B    1       ; port F data direction register         
.PFOR   DS.B    1       ; port F option register
        DS.B    1
        
reserved0 DS.B  8       ; unused

;**********************************************************************
;                        Miscellaneous 1 register
;**********************************************************************
   
.MISCR1  DS.B    1       ; miscellaneous register 1

;**********************************************************************
;                        SPI  registers
;**********************************************************************

.SPIDR  DS.B    1       ; SPI data register
.SPICR  DS.B    1       ; SPI control register
.SPISR  DS.B    1       ; SPI status register

reserved1 DS.B  5       ;unused 

;**********************************************************************
;                        Main Clock registers
;**********************************************************************

.MCCSR	DS.B	1			;Main Clock Control/Status register

;**********************************************************************
;                        Watchdog registers
;**********************************************************************

.WDGCR  	DS.B     1       ; watchdog control register
.CRSR		DS.B		1		; clock, reset, supply control/status register

;**********************************************************************
;                        EEPROM register
;**********************************************************************
.EECSR   DS.B     1      	; Data-EEPROM Control/Status register

reserved2 DS.B		4        ; unused
         
;**********************************************************************
;                        timer A registers
;**********************************************************************
    
.TACR2   DS.B    1       ; timer A control register 2
.TACR1   DS.B    1       ; timer A control register 1
.TASR    DS.B    1       ; timer status register
.TAIC1HR DS.B    1       ; timer A input capture 1 high register 
.TAIC1LR DS.B    1       ; timer A input capture 1 low register
.TAOC1HR DS.B    1       ; timer A output compare 1 high register
.TAOC1LR DS.B    1       ; timer A output compare 1 low register
.TACHR   DS.B    1       ; timer A counter high register
.TACLR   DS.B    1       ; timer A counter low register
.TAACHR  DS.B    1       ; timer A alternate counter high register
.TAACLR  DS.B    1       ; timer A alternate counter low register
.TAIC2HR DS.B    1       ; timer A input capture 2 high register 
.TAIC2LR DS.B    1       ; timer A input capture 2 low register
.TAOC2HR DS.B    1       ; timer A output compare 2 high register
.TAOC2LR DS.B    1       ; timer A output compare 2 low register
 
;**********************************************************************
;                        Miscellaneous 2 register
;**********************************************************************
   
.MISCR2  DS.B    1       ; miscellaneous register 2


;**********************************************************************
;                        timer B registers
;**********************************************************************

.TBCR2   DS.B    1       ; timer B control register 2
.TBCR1   DS.B    1       ; timer B control register 1
.TBSR    DS.B    1       ; timer B status register
.TBIC1HR DS.B    1       ; timer B input capture 1 high register 
.TBIC1LR DS.B    1       ; timer B input capture 1 low register
.TBOC1HR DS.B    1       ; timer B output compare 1 high register
.TBOC1LR DS.B    1       ; timer B output compare 1 low register
.TBCHR   DS.B    1       ; timer B counter high register
.TBCLR   DS.B    1       ; timer B counter low register
.TBACHR  DS.B    1       ; timer B alternate counter high register
.TBACLR  DS.B    1       ; timer B alternate counter low register
.TBIC2HR DS.B    1       ; timer B input capture 2 high register 
.TBIC2LR DS.B    1       ; timer B input capture 2 low register
.TBOC2HR DS.B    1       ; timer B output compare 2 high register
.TBOC2LR DS.B    1       ; timer B output compare 2 low register
    
;**********************************************************************
;                       SCI registers
;**********************************************************************
.SCISR  DS.B    1        ; sci status register    
.SCIDR  DS.B    1        ; sci data register
.SCIBRR DS.B    1        ; sci baud rate register    
.SCICR1 DS.B    1        ; sci control register 1
.SCICR2 DS.B    1        ; sci control register 2
.SCIERPR DS.B   1        ; sci extended receive prescaler register
         DS.B   1        ; reserved
.SCIETPR DS.B   1        ; sci extended transmit prescaler register

reserved5 DS.B  24       ; unused

;**********************************************************************
;                       ADC registers
;**********************************************************************

.ADCDR  DS.B    1       ; adc data register
.ADCCSR DS.B    1       ; adc control status register

   
   

;**********************************************************************
    segment byte at 80-FF 'ram0' ;Zero Page
;**********************************************************************


    WORDS           ; following addresses are 16 bit length
    
    

;**********************************************************************
;   for ST72334J2 or ST72334N2 with 8K ROM & 384 bytes RAM

 #ifdef ST72334N2
    segment byte at 100-1FF     'stack'
    segment byte at E000-FFDF   'rom' ;  
 #endif   
;**********************************************************************      

;**********************************************************************
    segment byte at C00-CFF 'eeprom' ;EEPROM area
;**********************************************************************

;**********************************************************************    
;   for ST72334J4 or ST72334N4 with 16K ROM & 512 bytes RAM
;
 #ifdef ST72334N4    
     segment byte at 100-1FF    'stack'
     segment byte at 200-27F    'ram1'
     segment byte at C000-FFDF  'rom'
 #endif     
;**********************************************************************  

;**********************************************************************
    segment byte at FFE0-FFFF 'vectit'
;**********************************************************************

        end
        
        
